function [r,tau,phir,phitau]=factrtau(obj)
% FACTRTAU da los factores de reflexión y de transmisión en términos de las  
%   amplitudes complejas de la función de onda de un objeto físico que  
%   interactúa  con un escalón de energía potencial.
%   Las fases (phi) de estos tres factores complejos se sitúan entre 0 y 2*pi.
%
%   [r,tau,phir,phitau]=FACTRTAU(obj)
%       >> obj      = Objeto escalón
%       << r        = Factor de reflexión
%       << tau      = Factor de transmisión
%       << phir     = Desfase por la reflexión (fase del factor r)
%       << phitau   = Desfase por la transmisión (fase del factor tau)
%
%   Olivier Pujol (2010)
%
%
%% Verificaciones

if (isa(obj,'escalón')==0),error('¡Tipo de objeto incorrecto!');end
if (obj.ke==0),error('¡Caso singular k=0!');end

%% Matriz escalón 

mat=matriz(obj);

%% Cálculo de los factores r y tau

r=-mat(2,1)/mat(2,2);
tau=sqrt(obj.ke/obj.ks)*(1/mat(2,2));
%
phir=mod(angle(r),pi);
phitau=mod(angle(tau),pi);
%
return;