function graf(obj,x,rho)
% GRAF ofrece una representación gráfica del escalón de energía potencial y de 
%   la densidad lineal de probabilidad de un objeto físico que interactúa 
%   con el escalón (dibujado) considerado. 
%
%   GRAF(obj,x,rho)
%       >> obj      = Objeto escalón
%       >> x        = Posición en el eje Ox 
%       >> rho      = Densidad lineal de probabilidad 
%
%   Olivier Pujol (2010)
%
%% Verificaciones

if (isa(obj,'escalón')==0),error('¡Tipo de objeto incorrecto!');end
%
xmin=x{1}(1);
xmax=x{2}(end);
if ( (xmin>=obj.x)||(xmax<=obj.x) ),error('¡El escalón está fuera del intervallo espacial!');end
Epmin=min(obj.Epe,obj.Eps);
Epmax=max(obj.Epe,obj.Eps);

%% Gráfico

figure

subplot(2,1,1);
hs=stairs([xmin obj.x xmax],[obj.Epe obj.Eps obj.Eps]);
set(hs,'LineWidth',2,'Color','b');grid on;box on;
axis([xmin xmax Epmin-.2 Epmax+.2]);
grid on;
box on;
set(gca,'Xminortick','on','Yminortick','on');
xlabel('{\itx} (nm)');
ylabel('Energía potencial (eV)');
%
subplot(2,1,2);
hp=plot(x{1},rho{1},x{2},rho{end});
set(hp,'LineWidth',2,'Color','r');
axis auto;
grid on;
box on;
set(gca,'Xminortick','on','Yminortick','on');
xlabel('{\itx} (nm)');
ylabel('{|\it\psi |^{2}}');
%
return;