function [x,psi,rho]=psirho(obj,incremento,xmin,xmax)
% PSIRHO determina la función de onda y la densidad lineal de probabilidad de  
%   un objeto físico que interactúa con un escalón de energía potencial. 
%   El cálculo se hace sobre un intervalo en el eje Ox entre xmin y xmax.
%
%   [x,psi,rho]=PSIRHO(obj,incremento,xmin,xmax)
%       >> obj			= Objeto escalón
% 	    >> incremento	= Incremento en el eje Ox
%       >> xmin			= Límite inferior en el eje Ox
%       >> xmax			= Límite superior en el eje Ox
%       << x			= Posición en el eje Ox
%       << psi			= Función de onda del objeto físico
%       << rho			= Densidad lineal de probabilidad del objeto físico
%
%   Olivier Pujol (2010)
%
if (isa(obj,'escalón')==0),error('¡Tipo de objeto incorrecto!');end
if (incremento>=0.01),error('El incremento en el eje Ox es demasiado grande!');end
if ( (xmin>=obj.x)||(xmax<=obj.x) ),error('¡El objeto escalón está fuera del intervalo espacial!');end
%
mat=matriz(obj);
%
x=cell(1,2);
psi=cell(1,2);
rho=cell(1,2);

%   Entrada
x{1}=linspace(xmin,obj.x,1+(obj.x-xmin)/incremento);
psi{1}=nan(size(x{1}));
psi{1}=(1/sqrt(obj.ke))*(exp(1i*obj.ke*(x{1}-obj.x)) ...
                        + (-mat(2,1)/mat(2,2))*exp(-1i*obj.ke*(x{1}-obj.x)) );
rho{1}=nan(size(x{1}));
rho{1}=psi{1}.*conj(psi{1});

%   Salida
x{2}=linspace(obj.x,xmax,1+(xmax-obj.x)/incremento);
psi{2}=nan(size(x{2}));
psi{2}=(1/sqrt(obj.ks))*(1/mat(2,2))*exp(1i*obj.ks*(x{2}-obj.x));
rho{2}=nan(size(x{2}));
rho{2}=psi{2}.*conj(psi{2});

% Normalización de las funciones psi y rho por la superficie (área) bajo la curva rho(x) entre 
% xmin y xmax.
área =  0.5*sum((rho{1}(1:end-1)+rho{1}(2:end))*incremento) + ...
        0.5*sum((rho{2}(1:end-1)+rho{2}(2:end))*incremento)/2;
rho{1}=rho{1}/área;
rho{2}=rho{2}/área;
%
psi{1}=psi{1}/sqrt(área);
psi{2}=psi{2}/sqrt(área);

return;