function [sys,E]=Epot(M,xt,Ep,m,E)
%   Epot permite construir el sistema {energía potencial – objeto físico}.
%
%   [sys,E]=Epot(M,xt,Ep,m,E)
%       >> M    = Nombres de los escalones
%       >> xt   = Posición de los escalones en el eje Ox
%       >> Ep   = Valores de la energía potencial
%       >> m    = Masa del objeto físico (respecto a la del electrón)
%       >> E    = Valores de la energía del objeto físico
%       << sys  = Sistema. Número de sistemas = número de valores de energía
%       << E    = Valores de E guardados (E=Ep está excluido para evitar la 
%                  singularidad k=0) 
%
%   Olivier Pujol (2010)
%
%% Verificaciones

if (m<=0),error('¡La masa tiene que ser positiva!');end
if (length(Ep)~=length(xt)+1),error('¡Número incorrecto de valores de Ep!');end

% Se tiene que comprobar que ningún valor de E se identifique a un valor cualquiera de Ep
for i=1:length(Ep)
    Ind=(abs(E-Ep(i))<eps); % Buscando los valores de E tal E=Ep
    E=E(Ind~=1);            % Los valores encontrados no se guardan
end
clear i Ind

%% Initialización

sys=cell(size(E));
k=cell(size(E));
escalón=cell(size(xt));

%% Construcción del sistema {Energía potencial-Objeto físico}
for n=1:length(E)
    k{n}=VectOnda(E(n),m,Ep);

    for p=1:length(xt)
        escalón{p}=escalón(M{p},xt(p),Ep(p),Ep(p+1),k{n}(p),k{n}(p+1));
    end
    sys{n}=Sistema(escalón{1:end});
end

return;