function [sys,E,Ep]=Rampa(Epi,Epf,pendiente,m,varargin)
% Rampa calcula las probabilidades de reflexión y de transmissión 
%   de una rampa de energía potencial y ofrece una representación  
%   gráfica en función de la energía del objeto físico.
%
%	[sys,E,Ep]=Rampa(Epi,Epif,pendiente,m,varargin) -- varargin indica un número variable de argumentos de entrada
%
%   	>> pendiente    = Pendiente de la energía potencial (J/m)
%   	>> m        = Masa (respecto a la del electron) del objeto físico
%   	>> varargin = Argumentos de entrada opcionales
%           >> nx   = Número de puntos en el eje Ox (defecto: 100)
%           >> nE   = Número de valores de la energía (defecto: 1000)
%           >> Emin = Valor mínimo de la energía (defecto: min(Ep))
%           >> Emax = Valor máximo de la energía (defecto: Ep(max(x)))
%
% Olivier Pujol : septembre 2013

%% Verificaciones

if (length(varargin)>4), error('¡Número incorrecto de argumentos de entrada opcionales!');end
if (nargin-length(varargin)~=4),error('¡Número incorrecto de argumentos de entrada no opcionales!');end
if (abs(pendiente)<=eps),error('La pendiente vale cero');end

if (pendiente>0 && Epi>Epf),error('Hay un problema en las energías entradas');end
if (pendiente<0 && Epf>Epi),error('Hay un problema en las energías entradas');end

%% Argumentos opcionales de entrada

switch length(varargin)
    case 0
        nx=100;                     % Valor por defecto del número de puntos en el eje Ox
        nE=500;                     % Valor par defecto del número de valores de la energía
    case 1
        nx=varargin{1};             % Valor por defecto del número de puntos en el eje Ox
        nE=500;                     % Valor par defecto del número de valores de la energía
    case 2
        nx=varargin{1};             % Valor por defecto del número de puntos en el eje Ox
        nE=varargin{2};             % Valor par defecto del número de valores de la energía
    case 4
        nx=varargin{1};             % Valor del número de puntos en el eje Ox
        nE=varargin{2};             % Valor del número de valores de la energía
        E=linspace(varargin{3},varargin{4},nE);     % Vector de los valores de la energía
    otherwise
        ('Número incorrecto de argumentos de entrada opcionales');
end

%% Energía potencial

% Construcción
x=linspace(0,(Epf-Epi)/pendiente,nx);       % Intervalo espacial 
Epc=pendiente*x+Epi;                        % Energía potencial lineal (pendiente en eV/nm)

% Digitalización
[M,xt,Ep]=digitalización(x,Epc);

% Se añade los escalones inicial y final de energía respectiva Epi en x=0
% y Epf en x=(Epf-Epi)/pendiente
M=['Mi' M 'Mf'];
Ep=[Epi;Ep;Epf];
xt=[0;xt;(Epf-Epi)/pendiente];

% Vector de los valores de la energía
if (length(varargin)~=4 && pendiente >0)
    E=linspace(Epi,2*Epf,nE);
end    
if (length(varargin)~=4 && pendiente <0)
    E=linspace(2*Epi,Epf,nE);
end    

%% Probabilidad de reflexión y de transmisión

[sys,E]=Epot(M,xt,Ep,m,E);          % Fabricación del sistema
TES=matriz(sys);

[R,T]=factRT(sys,TES);
grafE(sys,E,T);

return;