function sys=Sistema(varargin)
% Sistema da una estructura (matriz) cuyas celdas contienen, cada una, las
%   características de las energías potenciales elementales que forman la
%   energía potencial total, y los vectores de onda (entrada y salida) del
%   objeto físico. 
%   El sistema es: {energía potencial – objeto físico}.
%
%   sys=Sistema(varargin) -- varargin indica varios argumentos de entrada.
%       >> varargin 	= Energías potenciales elementales (número variable)
%       << sys 			= Sistema
%
% Las energías potenciales elementales tienen que ser escritas siguiendo el orden 
% en el que el que se encuentran, progresando del emisor hasta el receptor.
%
%   Olivier Pujol (2010)
%
if (nargin<1), error('¡Número de argumentos de entrada incorrecto!');end
%
sys=cell(1,length(varargin));   % Inicialización
%
for k=1:length(varargin)
    sys{k+1}=varargin{k};
end
sys{1}=[get(varargin{1},'EnergíaPotencialEntrada') ...
        get(varargin{end},'EnergíaPotencialSalida') ...
        get(varargin{1},'VectorOndaEntrada') ...
        get(varargin{end},'VectorOndaSalida') ...
        get(varargin{1},'Posición') ...
        get(varargin{end},'Posición')];
%
return;