function [r,tau,phir,phitau]=factrtau(sys,TES)
% FACTRTAU da los factores de reflexión y de transmisión en términos de las  
%   amplitudes complejas de la función de onda de un objeto físico que  
%   interactúa  con un escalón de energía potencial.
%   Las fases (phi) de estos tres factores complejos se sitúan entre 0 y 2*pi.
%
%   [r,tau,phir,phitau]=FACTRTAU(sys,TES)
%       >> sys      = Sistema
%       >> TES      = Matriz de transferencia del sistema
%       << r        = Factor de reflexión
%       << tau      = Factor de transmisión
%       << phir     = Desfase por la reflexión (fase de r)
%       << phitau   = Desfase por la transmisión (fase de tau)
%
%   Olivier Pujol (2010)
%
if (nargin~=2),error('¡Número incorrecto de argumentos de entrada!');end
%
nE=size(TES,2); % Número de valores de la energía
r=nan(1,nE);
tau=nan(1,nE);
phir=nan(1,nE);
phitau=nan(1,nE);
%
for iE=1:nE
    r(iE)=-TES{iE}(2,1)/TES{iE}(2,2);
    tau(iE)=sqrt(sys{iE}{1}(3)/sys{iE}{1}(4))*(1/TES{iE}(2,2));
    phir(iE)=mod(angle(r(iE)),pi);
    phitau(iE)=mod(angle(tau(iE)),pi);
end
%
return;
